<template>
  <!--支持全屏缩放-->
  <a-modal
    :visible="visible"
    :title="title"
    switchFullscreen
    @ok="handleSubmit"
    @cancel="close"
    style="top:50px"
    cancelText="关闭"
    :width="1600"
  >
    <a-card :bordered="false">
      <div class="table-page-search-wrapper">
        <a-form
          layout="inline"
          @keyup.enter.native="searchQuery"
        >
          <a-row :gutter="24">
            <a-col
              :md="6"
              :sm="6"
            >
              <a-form-item label="统一编码">
                <a-input
                  placeholder="请输入统一编码"
                  v-model="queryParam.num"
                />
              </a-form-item>
            </a-col>
            <a-col
              :md="6"
              :sm="6"
            >
              <a-form-item label="设备名称">
                <a-input
                  placeholder="设备名称"
                  v-model="queryParam.name"
                />
              </a-form-item>
            </a-col>
            <!-- 按中心查询 -->
            <a-col
              :md="6"
              :sm="6"
            >
              <a-form-item label="中心">
                <j-dict-select-tag
                  allow-clear
                  placeholder="请选择中心"
                  :triggerChange="true"
                  dictCode="mom_base_area,name,id,del_flag!='1' and type='1'"
                  v-model="queryParam.workCenterId"
                />
              </a-form-item>
            </a-col>
            <a-col
              :md="6"
              :sm="6"
            >
              <a-form-model-item
                label="下次三保时间"
                prop="ranges"
              >
                <a-range-picker
                  v-model="ranges"
                  style="width:100%"
                  format="YYYY-MM-DD HH:mm:ss"
                  showTime
                  :placeholder="[ '开始时间', '结束时间']"
                  @change="changeDate"
                />
              </a-form-model-item>
            </a-col>

            <a-col :md="3">
              <span
                style="float: left;overflow: hidden;"
                class="table-page-search-submitButtons"
              >
                <a-button
                  type="primary"
                  @click="searchQuery"
                  icon="search"
                >查询</a-button>
                <a-button
                  @click="searchReset"
                  icon="reload"
                  style="margin-left: 10px"
                >重置</a-button>
              </span>
            </a-col>
          </a-row>
        </a-form>
      </div>
      <a-table
        ref="table"
        :scroll="scrollTrigger"
        size="middle"
        rowKey="id"
        bordered
        :columns="columns"
        :dataSource="dataSource"
        :pagination="ipagination"
        :rowSelection="rowSelection"
        :loading="loading"
        @change="handleTableChange"
      >
      </a-table>
    </a-card>
  </a-modal>
</template>

<script>
import { filterObj } from '@/utils/util'
import { getAction } from '@/api/manage'
import { JeecgListMixin } from '@/mixins/JeecgListMixin'

export default {
  name: 'JSelectToolingModal',
  mixins: [JeecgListMixin],
  components: {},
  props: {
    maintenanceType: {
      type: String,
      default: '',
      required: true
    }

  },
  data() {
    return {
      queryParam: {
      },
      ranges: [],
      columns: [
        {
          title: '#',
          dataIndex: 'id',
          key: 'rowIndex',
          width: 50,
          align: 'center',
          customRender: function (t, r, index) {
            return parseInt(index) + 1
          }
        },
        {
          title: '统一编码',
          align: 'center',
          dataIndex: 'num',
          // width: 200
        },
        {
          title: '设备名称',
          align: 'center',
          dataIndex: 'name',
          // width: 200
        },
        {
          title: '设备型号',
          align: 'center',
          dataIndex: 'model',
          // width: 200
        },
        {
          title: '设备规格',
          align: 'center',
          dataIndex: 'specification',
          // width: 200
        },
        {
          title: 'ABC标识',
          align: "center",
          dataIndex: 'equipmentImportanceId',
          // width: 100
        },
        {
          title: '关键设备标识',
          align: "center",
          dataIndex: 'specificEquipment_dictText',
          width: 100
        },
        {
          title: '设备状态',
          align: 'center',
          // dataIndex: 'equipmentStatus_dictText',
          // width: 100
        },
        {
          title: '技术状态',
          align: 'center',
          dataIndex: 'technologyStatus_dictText',
          // width: 100
        },
        //下次三保时间
        {
          title: '下次三保时间',
          align: 'center',
          dataIndex: 'nextThirdMaintenanceTime',
          // width: 200
        },
        //中心
        {
          title: '中心',
          align: 'center',
          dataIndex: 'workCenterId_dictText',
          // width: 200
        },
      ],
      selectedRowKeys: [],
      oldSlelectRows: [],
      scrollTrigger: {},
      dataSource: [],
      selectionRows: [],
      title: '根据查询结果选择精度参数',
      ipagination: {
        current: 1,
        pageSize: 10,
        pageSizeOptions: ['5', '10', '30', '50', '100'],
        showTotal: (total, range) => {
          return range[0] + '-' + range[1] + ' 共' + total + '条'
        },
        showQuickJumper: true,
        showSizeChanger: true,
        total: 0
      },
      isorter: {
        column: 'num',
        order: 'desc'
      },
      departTree: [],
      visible: false,
      loading: false,
      url: {
        list: '/eam/equipment/planEquipmentList',
        getStandards: '/eam/equipmentMaintenancePlan/getStandards'
      },
    }
  },
  computed: {
    rowSelection() {
      return {
        type: 'checkbox',
        onChange: (selectedRowKeys, selectedRows) => {
          this.selectedRowKeys = selectedRowKeys;
          this.onSelectChange(selectedRows);
        },
        getCheckboxProps: record => ({
          props: {
            disabled: record.distable
          },
        }),
        selectedRowKeys: this.selectedRowKeys,
      };
    },
  },
  watch: {

  },
  created() {
  },
  methods: {

    async loadData(arg) {
      if (arg === 1) {
        this.ipagination.current = 1;
      }
      let that = this
      this.loading = true
      // this.queryParam.versionStatus = '2'
      // this.queryParam.type = 'daily'
      this.queryParam.isLine = 'no';
      let params = this.getQueryParams()//查询条件
      await getAction(this.url.list, params).then((res) => {
        if (res.success) {
          for (let i = 0; i < res.result.records.length; i++) {
            if (that.oldSlelectRows.indexOf(res.result.records[i].id) > -1) {
              res.result.records[i].distable = true;
            } else {
              res.result.records[i].distable = false;
            }
          }
          this.dataSource = res.result.records;
          this.ipagination.total = res.result.total;
        }
        if (res.code === 510) {
          this.$message.warning(res.message)
        }
        this.loading = false;
      })
    },
    showModal(oldSlelectRows) {
      this.oldSlelectRows = oldSlelectRows;
      this.visible = true;
      this.loadData(1);
    },
    getQueryParams() {
      let param = Object.assign({}, this.queryParam, this.isorter);
      param.field = this.getQueryField();
      param.pageNo = this.ipagination.current;
      param.pageSize = this.ipagination.pageSize;
      return filterObj(param);
    },
    //查询条件处理
    getQueryField() {
      let str = 'id,';
      for (let a = 0; a < this.columns.length; a++) {
        str += ',' + this.columns[a].dataIndex;
      }
      return str;
    },
    searchReset(num) {
      let that = this;
      this.queryParam = [];
      this.ranges = [];
      if (num !== 0) {
        that.loadData(1);
      }

      that.selectborrowIds = [];
    },
    close() {
      this.searchReset(0);
      this.selectedRowKeys = [];
      this.visible = false;
    },
    handleTableChange(pagination, filters, sorter) {
      //TODO 筛选
      if (Object.keys(sorter).length > 0) {
        this.isorter.column = sorter.field;
        this.isorter.order = 'ascend' === sorter.order ? 'asc' : 'desc';
      }
      this.ipagination = pagination;
      this.loadData();
    },
    handleSubmit() {
      this.loading = true
      let that = this;
      var ids = '';
      if (this.selectionRows.length == 0) {
        that.$message.warning("请选择保养设备");
        this.loading = false;
        return false;
      }
      for (var i = 0; i < this.selectionRows.length; i++) {
        ids = ids + this.selectionRows[i].id + ',';
      }
      getAction(this.url.getStandards, { ids: ids, maintenanceType: this.maintenanceType }).then(res => {
        if (res.success) {
          if (res.result.records.length !== that.selectionRows.length) {
            that.$message.warning(res.result.message);
          }
          that.$emit('selectionEquipmentRows', res.result.records);
          that.searchReset(0)
          that.close();
        }
      }).finally(res => {
        this.loading = false;
      })


    },
    changeDate(date, dateString) {
      this.queryParam.startTime = dateString[0].format('YYYY-MM-DD HH:mm:ss');
      this.queryParam.endTime = dateString[1].format('YYYY-MM-DD HH:mm:ss');
    },
    onSelectChange(selectionRows) {
      this.selectionRows = selectionRows;
    },
    searchQuery() {
      this.loadData(1);
    },
  }
}
</script>

<style scoped>
.ant-table-tbody .ant-table-row td {
  padding-top: 10px;
  padding-bottom: 10px;
}

#components-layout-demo-custom-trigger .trigger {
  font-size: 18px;
  line-height: 64px;
  padding: 0 24px;
  cursor: pointer;
  transition: color 0.3s;
}
</style>